**Example 1: 查询配置发布信息**



Input: 

```
tccli tsf DescribeConfigReleases --cli-unfold-argument  \
    --ConfigId dcfg-zvw6kxa8
```

Output: 
```
{
    "Response": {
        "RequestId": "2cee7c95-08aa-45fa-9a1c-7016b7b1fcbf",
        "Result": {
            "TotalCount": 0,
            "Content": []
        }
    }
}
```

